==> haskell-glob-0.10.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.10.0
id: Glob-0.10.0-LBEPm6lyuRvG60U16D4Lpv
key: Glob-0.10.0-LBEPm6lyuRvG60U16D4Lpv
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 654d429ec2585105d5a7ed66342df319
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Glob-0.10.0
hs-libraries: HSGlob-0.10.0-LBEPm6lyuRvG60U16D4Lpv
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.10.0
id: Glob-0.10.0-AFt8pmz7TZ1LmOfQNwvLR2
key: Glob-0.10.0-AFt8pmz7TZ1LmOfQNwvLR2
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 70ac4be0715f46e5616fac8480e1611d
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Glob-0.10.0
hs-libraries: HSGlob-0.10.0-AFt8pmz7TZ1LmOfQNwvLR2
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-3pVAAQTTgIh7eacL2MCN3o filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
